
galton <- read.csv("http://bcss.org.my/data/galtonF.csv", comment="#")
head(galton)
str(galton)

plot(Daughter ~ Mother, data=galton)
(fit <- lm(Daughter ~ Mother, data=galton) )
abline(fit, col='red')
abline(0, 1)

# Bayesian analysis
# =================
library(jagsUI)
library(wiqid)

# Intercept is nonsense! Daughter's height when mother's height = 0??
# Centre the mothers' heights:
mean(galton$Mother)  # 162.84
motherC <- galton$Mother - mean(galton$Mother)
(fit2 <- lm(Daughter ~ motherC, data=galton) )
summary(fit2)
# Now intercept = daughter's height when mother is average height.

# JAGS analysis
modelText <- "
model{
  # Likelihood
  for(i in 1:N) {
    mu[i] <- b0 + b1 * parent[i]
    child[i] ~ dnorm(mu[i], tau)
  }
  # Priors
  b0 ~ dgamma(shape, rate)
  b1 ~ dnorm(0, 0.01)
  sigma ~ dunif(0, 10)
  tau <- 1/sigma^2
}"
writeLines(modelText, con="galton.jags")

# Priors: for intercept, gamma with mean 160 cm and big sd, 20
curve(dgamma2(x, 160, 20), 100, 250)
gampars <- getGammaPar(160, 20)

jagsData <- list(child=galton$Daughter, parent=motherC, N=length(motherC),
  shape=gampars[1], rate=gampars[2])
str(jagsData)

wanted <- c("b0", "b1", "sigma")

out <- jags(jagsData, NULL, wanted, "galton.jags",
  n.chains=3, n.iter=1e4, n.burn=0, parallel=TRUE, DIC=FALSE)
out
diagPlot(out)

# Plot posterior
# ==============
# Convert to a 'mcmcOutput' object
bw <- mcmcOutput(out)
plot(bw, "b1")
plot(bw, "sigma")


