
# Analysis of Galton's (1886) data with NIMBLE

galton <- read.csv("http://bcss.org.my/data/galtonF.csv", comment="#")
head(galton)
str(galton)

plot(Daughter ~ Mother, data=galton)
(fit <- lm(Daughter ~ Mother, data=galton) )
abline(fit, col='red')
abline(0, 1)

# Bayesian analysis
# =================
library(nimble)
library(wiqid)  # for getGammaPar

# Centre the mothers' heights:
mean(galton$Mother)  # 162.84
motherC <- galton$Mother - mean(galton$Mother)
(fit2 <- lm(Daughter ~ motherC, data=galton) )
summary(fit2)
# Now intercept = daughter's height when mother is average height.

# Write the model for NIMBLE
galton.code <- nimbleCode({
  # Likelihood
  for(i in 1:N) {
    mu[i] <- b0 + b1 * parent[i]
    child[i] ~ dnorm(mu[i], sd=sigma)
  }
  # Priors
  b0 ~ dgamma(shape, rate)
  b1 ~ dnorm(0, 0.01)
  sigma ~ dunif(0, 10)
})

# Priors: for intercept, gamma with mean 160 cm and big sd, 20
curve(dgamma2(x, 160, 20), 100, 250)
gampars <- getGammaPar(160, 20)

nimData <- list(child=galton$Daughter)
nimConst <- list(parent=motherC, N=length(motherC),
  shape=gampars[1], rate=gampars[2])

wanted <- c("b0", "b1", "sigma")

nimout <- nimbleMCMC(galton.code, data=nimData, constants=nimConst, monitors=wanted,
    nchains=3, niter=11e3, nburnin=1e3, samplesAsCodaMCMC=TRUE)

# Convert to a 'mcmcOutput' object
( mco <- mcmcOutput(nimout) )
diagPlot(mco)
plot(mco, c("b1", "sigma"))
